@@ -3,18 +3,18 @@ import os.path as osp
 import numpy as np
 import PIL.Image
 
-from labelme.utils.draw import label_colormap
-
 
 def lblsave(filename, lbl):
+    import imgviz
+
     if osp.splitext(filename)[1] != '.png':
         filename += '.png'
     # Assume label ranses [-1, 254] for int32,
     # and [0, 255] for uint8 as VOC.
     if lbl.min() >= -1 and lbl.max() < 255:
         lbl_pil = PIL.Image.fromarray(lbl.astype(np.uint8), mode='P')
-        colormap = label_colormap(255)
-        lbl_pil.putpalette((colormap * 255).astype(np.uint8).flatten())
+        colormap = imgviz.label_colormap()
+        lbl_pil.putpalette(colormap.flatten())
         lbl_pil.save(filename)
     else:
         raise ValueError(
